@@ -98,7 +98,11 @@ void AlbumView::setAlbum(Spotify::Album* pAlbum)
         if(!status)
         {
             //error occured
+#ifdef Q_WS_MAEMO_5
             QMaemo5InformationBox::information(this,tr("Fetching of album details failed!"));
+#else
+            Banner::information(this,tr("Fetching of album details failed!"));
+#endif
         }
         else
         {
@@ -107,7 +111,9 @@ void AlbumView::setAlbum(Spotify::Album* pAlbum)
                 m_AlbumCaption.setText(pAlbum->getName() + " (" + QString::number(pAlbum->getYear()) + ")"); //set album title
             else
                 m_AlbumCaption.setText(pAlbum->getName()); //set album title (no year)
+#ifdef Q_WS_MAEMO_5
             setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true);
+#endif
         }
     }
 }
@@ -131,7 +137,11 @@ void AlbumView::OnAlbumBrowserReady(Spotify::AlbumBrowser* browser, qint32 calle
             if(error.isError())
             {
                 //error occured (album browse request failed)
+#ifdef Q_WS_MAEMO_5
                 QMaemo5InformationBox::information(this,tr("Fetching of album details failed: ") + error.toString());
+#else
+                Banner::information(this,tr("Fetching of album details failed: ") + error.toString());
+#endif
             }
             else
             {
@@ -153,8 +163,9 @@ void AlbumView::OnAlbumBrowserReady(Spotify::AlbumBrowser* browser, qint32 calle
                 addTracks();
             }
         }
-
+#ifdef Q_WS_MAEMO_5
         setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
+#endif
     }
 }
 
@@ -222,11 +233,14 @@ void AlbumView::OnTrackActivated(QModelIndex trackIndex)
         if(trackIndex.data(ListViewDelegate::customDataRole).toInt()!=-1)
         {
             m_pAlbumTrackView->setEnabled(false); //disable listview temporarily
-
+#ifdef Q_WS_MAEMO_5
             setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //show progress indicator
+#endif
             emit playQueueSet(m_pAlbumBrowser->getTracks(false),m_pAlbumTrackView->currentIndex().row()); //signal that playqueue has been set / updated
             hide();
+#ifdef Q_WS_MAEMO_5
             setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
+#endif
             m_pAlbumTrackView->setEnabled(true); //re-enable the listview
         }
     }
