@@ -28,7 +28,6 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
     m_SearchOptionLayout.addWidget(&m_maxSearchAlbumsInput,1,1);
     m_SearchOptionLayout.addWidget(&m_maxSearchArtistsCaption,2,0);
     m_SearchOptionLayout.addWidget(&m_maxSearchArtistsInput,2,1);
-
     m_SearchOptions.setLayout(&m_SearchOptionLayout);
 
     m_MinBufferLenInput.setInputMask("900");
@@ -36,7 +35,6 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
     m_BufferingOptionLayout.addWidget(&m_MinBufferLenCaption,0,0);
     m_BufferingOptionLayout.addWidget(&m_MinBufferLenInput,0,1);
     m_BufferingOptionLayout.addWidget(&m_PreBufferNextTrackSelection,1,0,1,-1);
-
     m_BufferingOptions.setLayout(&m_BufferingOptionLayout);
 
     //set up bitrate selection value button / selector
@@ -75,11 +73,8 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
 #ifdef Q_WS_MAEMO_5
 
     QStringListModel *pLangListModel = new QStringListModel(this);
-
     pLangListModel->setStringList(m_UILangList);
-
     m_pUILangSelector = new QMaemo5ListPickSelector(this);
-
     m_pUILangSelector->setModel(pLangListModel);
     m_UILangBtn.setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered); // Maemo5 style guide wants the menu entries centered.
     m_UILangBtn.setPickSelector(m_pUILangSelector);
@@ -97,11 +92,8 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
 #ifdef Q_WS_MAEMO_5
 
     QStringListModel *pListModel = new QStringListModel(this);
-
     pListModel->setStringList(m_orientationList);
-
     m_pOrientationSelector = new QMaemo5ListPickSelector(this);
-
     m_pOrientationSelector->setModel(pListModel);
     m_OrientationBtn.setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered); // Maemo5 style guide wants the menu entries centered.
     m_OrientationBtn.setPickSelector(m_pOrientationSelector);
@@ -115,6 +107,24 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
     m_LastFMUserIDInput.setInputMethodHints(Qt::ImhNoAutoUppercase);
     m_LastFMPasswordInput.setEchoMode(QLineEdit::Password); //set password mode for input field
 
+    //advanced settings
+
+    m_pathLocationList << tr("Internal EMMC") << tr("Memory (SD) card");
+
+#ifdef Q_WS_MAEMO_5
+
+    QStringListModel *pPathListModel = new QStringListModel(this);
+    pPathListModel->setStringList(m_pathLocationList);
+    m_pPathSelector = new QMaemo5ListPickSelector(this);
+    m_pPathSelector->setModel(pPathListModel);
+    m_PathSelBtn.setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered); // Maemo5 style guide wants the menu entries centered.
+    m_PathSelBtn.setPickSelector(m_pPathSelector);
+    m_AdvancedOptionLayout.addWidget(&m_PathSelBtn,0,0,1,-1);
+
+#endif
+
+    m_AdvancedOptions.setLayout(&m_AdvancedOptionLayout);
+
     m_ScrobblingOptionLayout.addWidget(&m_EnableScrobblingSelection,0,0,1,2);
     m_ScrobblingOptionLayout.addWidget(&m_LastFMUserIDCaption,1,0);
     m_ScrobblingOptionLayout.addWidget(&m_LastFMUserIDInput,1,1);
@@ -141,6 +151,7 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
 #endif
     m_GridLayout.addWidget(&m_PauseOnHSDisconnSelection,8,0,1,-1);
     m_GridLayout.addWidget(&m_ScrobblingOptions,9,0,1,-1);
+    m_GridLayout.addWidget(&m_AdvancedOptions,10,0,1,-1);
 
     m_MainAreaLayout.setLayout(&m_GridLayout);
     m_MainArea.setWidget(&m_MainAreaLayout);
@@ -174,6 +185,7 @@ void SettingsDialog::setCapsLandscape()
     m_PreferredSyncBitrateBtn.setText(tr("Preferred offline sync. bitrate"));
     m_UILangBtn.setText(tr("UI Language"));
     m_OrientationBtn.setText(tr("Display orientation"));
+    m_PathSelBtn.setText(tr("Cache / settings location"));
 #endif
     m_AllowMobileSyncSelection.setText(tr("Allow sync. over 3G"));
     m_PauseOnHSDisconnSelection.setText(tr("Pause on headset unplugged"));
@@ -181,6 +193,7 @@ void SettingsDialog::setCapsLandscape()
     m_EnableScrobblingSelection.setText(tr("Enable scrobbling to Last.fm"));
     m_LastFMUserIDCaption.setText(tr("Last.fm username"));
     m_LastFMPasswordCaption.setText(tr("Last.fm password"));
+    m_AdvancedOptions.setTitle(tr("Advanced settings"));
     m_SaveSettingsBtn.setText(tr("Save"));
     m_HideCoverArt.setText(tr("Hide coverart in Now Playing"));
 }
@@ -202,6 +215,7 @@ void SettingsDialog::setCapsPortrait()
     m_PreferredSyncBitrateBtn.setText(tr("Preferred offline bitrate"));
     m_UILangBtn.setText(tr("UI Language"));
     m_OrientationBtn.setText(tr("Display orientation"));
+    m_PathSelBtn.setText(tr("Cache / settings location"));
 #endif
     m_AllowMobileSyncSelection.setText(tr("Allow sync. over 3G"));
     m_PauseOnHSDisconnSelection.setText(tr("Pause on headset unplugged"));
@@ -209,6 +223,7 @@ void SettingsDialog::setCapsPortrait()
     m_EnableScrobblingSelection.setText(tr("Enable Last.fm scrobbling"));
     m_LastFMUserIDCaption.setText(tr("Last.fm username"));
     m_LastFMPasswordCaption.setText(tr("Last.fm password"));
+    m_AdvancedOptions.setTitle(tr("Advanced settings"));
     m_SaveSettingsBtn.setText(tr("Save"));
     m_HideCoverArt.setText(tr("Hide coverart in Now Playing"));
 }
@@ -311,6 +326,25 @@ void SettingsDialog::readSettings()
             m_LastFMUserIDInput.setText("");
             m_LastFMPasswordInput.setText("");
         }
+
+        m_strCacheDirPath = m_pAppSettings->value("QSpot/cacheLocation", CACHE_PATH_EMMC + "/" + CACHE_DIR_NAME_DEFAULT).toString();
+        if(m_strCacheDirPath==CACHE_PATH_MMC + "/" + CACHE_DIR_NAME_DEFAULT)
+        { //cache location set to memory (SD) card
+#ifdef Q_WS_MAEMO_5
+            m_pPathSelector->setCurrentIndex(1);
+            m_PathSelBtn.setDisabled(false);
+#endif
+        }
+        else
+        { //cache location set to internal EMMC
+#ifdef Q_WS_MAEMO_5
+            m_pPathSelector->setCurrentIndex(0);
+            if(!mmcPresent())
+            { //disable value button in case a memory (SD) card is not present
+                m_PathSelBtn.setDisabled(true);
+            }
+#endif
+        }
     }
 }
 
@@ -320,6 +354,7 @@ void SettingsDialog::saveSettings()
 
     bool settingsChanged = false;
     qint32 selBitrate, selUILang, selOrientation;
+    bool cacheLocationChanged = false;
 
     if(m_pAppSettings)
     {
@@ -463,6 +498,28 @@ void SettingsDialog::saveSettings()
             settingsChanged = true;
         }
 
+#ifdef Q_WS_MAEMO_5
+        if(m_pPathSelector->currentIndex()==0 && m_strCacheDirPath!=CACHE_PATH_EMMC+"/"+CACHE_DIR_NAME_DEFAULT)
+        {
+            m_pAppSettings->setValue("QSpot/cacheLocation",CACHE_PATH_EMMC+"/"+CACHE_DIR_NAME_DEFAULT);
+            cacheLocationChanged = true;
+        }
+        else if(m_pPathSelector->currentIndex()==1 && m_strCacheDirPath!=CACHE_PATH_MMC+"/"+CACHE_DIR_NAME_DEFAULT)
+        {
+            m_pAppSettings->setValue("QSpot/cacheLocation",CACHE_PATH_MMC+"/"+CACHE_DIR_NAME_DEFAULT);
+            cacheLocationChanged = true;
+        }
+#endif
+
+        if(cacheLocationChanged)
+        {
+#ifdef Q_WS_MAEMO_5
+            QMaemo5InformationBox::information(this,tr("Please restart QSpot for cache location change to take effect!"));
+#else
+            Banner::information(this,tr("Please restart QSpot for cache location change to take effect!"));
+#endif
+        }
+
         if(settingsChanged)
             emit settingsSaved();
     }
@@ -515,3 +572,34 @@ void SettingsDialog::OnOrientationChanged()
          setCapsPortrait();
     }
 }
+
+bool SettingsDialog::mmcPresent()
+{
+    //Returns true in case memory (SD) card is present; otherwiser returns false.
+    //SD card is detected by checking for presence of /media/mmc1 in /etc/mtab.
+
+   QFile mtabFile("/etc/mtab");
+   QString strLine;
+
+   if(!mtabFile.open(QIODevice::ReadOnly))
+       return false;
+
+   QTextStream input(&mtabFile);
+   while (!input.atEnd())
+   {
+     strLine = input.readLine();
+     if(strLine.contains("/media/mmc1")) //SD (MMC) card present and mounted
+     {
+         mtabFile.close();
+         return true;
+     }
+   }
+
+   mtabFile.close();
+   return false;
+}
+
+void SettingsDialog::OnPathSelectionBtn()
+{
+    //user has clicked the cache / setting path selection button
+}
