@@ -13,9 +13,7 @@ TrackView::TrackView(Spotify::Session* pSession, QWidget* parent) :
 
         m_pSession = pSession; //set the Spotify session instance
         connect(m_pSession,SIGNAL(albumBrowserReady(Spotify::AlbumBrowser*,qint32)),SLOT(OnAlbumBrowseReady(Spotify::AlbumBrowser*,qint32)));
-
         m_CallerID = TRACKVIEW_ID;
-
         m_lastTimeTrackActivated.start();
 
         //init the track listview instance
@@ -107,6 +105,12 @@ Spotify::Track* TrackView::getTrackFromModelIndex(QModelIndex index)
     return track;
 }
 
+Spotify::Playlist* TrackView::getActivePlaylist()
+{
+    //returns pointer to active playlist
+    return m_pPlaylist;
+}
+
 void TrackView::OnPlayAlbumAction()
 {
     //request to play the album of currently selected track
@@ -386,7 +390,7 @@ void TrackView::addTracks(Spotify::Playlist* playlist)
 #endif
 }
 
-void TrackView::addTrackListModelItem(Spotify::Track* track, int pos)
+void TrackView::addTrackListModelItem(Spotify::Track* track, qint32 pos)
 {
     //add track item to the track list item model
 
@@ -394,14 +398,18 @@ void TrackView::addTrackListModelItem(Spotify::Track* track, int pos)
     QPixmap iconMap;
 
     iconMap.load("/opt/qspot/images/icon-type-song-color.png"); //load song (track) type icon from file
-
     QIcon trackTypeIcon(iconMap);
+    iconMap.load("/opt/qspot/images/icon-type-song-color-offline.png"); //load song (track) offline type icon from file
+    QIcon trackTypeOfflineIcon(iconMap);
 
     //appends new track item to the track list model
     QStandardItem *trackItem = new QStandardItem();
     trackItem->setEditable(false);
     strSubHeader = "";
-    trackItem->setData(trackTypeIcon,ListViewDelegate::iconRole);
+    if(!track->isOffline()) //track not available offline
+        trackItem->setData(trackTypeIcon,ListViewDelegate::iconRole);
+    else //track available offline
+        trackItem->setData(trackTypeOfflineIcon,ListViewDelegate::iconRole);
     trackItem->setData(track->getName(),ListViewDelegate::headerRole);
     trackItem->setData(track->getDurationAsString(),ListViewDelegate::subHeaderRightJustifyRole);
     trackItem->setData(pos,Qt::UserRole); //associate position in track instances list with list item */
