@@ -18,7 +18,11 @@
 #include <QIcon>
 #include <QDebug>
 #include <QKeyEvent>
-#include <QMaemo5InformationBox>
+#ifdef Q_WS_MAEMO_5
+    #include <QMaemo5InformationBox>
+#else
+    #include "Banner.h"
+#endif
 #include "ListViewDelegate.h"
 #include "PickSelectorAction.h"
 #include "CListView.h"
@@ -49,6 +53,8 @@ public:
     void setPlaylist(Spotify::Playlist* pPlaylist); //set the playlist for which tracks should be displayed
     void setSearchResults(Spotify::Search* pSearch); //set the search results to be displayed
 
+    Spotify::Playlist* getActivePlaylist();  //returns pointer to active playlist
+
 protected:
 
     void keyPressEvent(QKeyEvent *evt);
