@@ -24,6 +24,7 @@ namespace Spotify
             sp_track* getTrack() const { return m_track; }
             bool isLoaded() const { return m_loaded; }
             bool isAvailable() const { return m_available; }
+            bool isOffline() { return m_isOffline; }
             Spotify::Artist* getArtist() { return m_artist; }
             Spotify::Album* getAlbum() { return m_album; }
             QString getName() { return m_name; }
@@ -44,6 +45,7 @@ namespace Spotify
             sp_track* m_track;
             bool m_loaded;
             bool m_available;
+            bool m_isOffline;
             Spotify::Artist* m_artist;
             Spotify::Album* m_album;
             QString m_name;
@@ -52,14 +54,6 @@ namespace Spotify
             int m_disc;
             int m_index;
             bool m_hasRef;
-
-            /*int m_intduration;
-            QString m_artist;
-            QString m_title;
-            QString m_album;
-            QString m_uri;
-
-            const byte* m_coverArtID;*/
     };
 } // namespace Spotify
 
