@@ -1,6 +1,6 @@
 #ifndef USER_H
 #define USER_H
-#include <spotify/api.h>
+#include <libspotify/api.h>
 #include <QObject>
 
 namespace Spotify
